#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: gdmap
# PROJECT HOMEPAGE 	: http://gdmap.sourceforge.net
# SOURCE           	: http://downloads.sourceforge.net/gdmap/
#
# AUTHOR         	: skywatcher (skywatcher|AT|netsons|DOT|org, simone antoniucci)
# LATEST REVISION	: 2008/06/18
#
# BUILD ONLY DEPS	: -
# NOTES				: -

### Setting main variables
NAME="gdmap"
VERSION="0.8.1"
ARCH="i486"
CPU="i686"
BUILD=54.1

HOMEPAGE="http://gdmap.sourceforge.net"
DESCRIPTION="Disk space visualizer"
SRCLNK="http://downloads.sourceforge.net/gdmap/$NAME-$VERSION.tar.gz"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=$NAME-$VERSION.tar.gz
SRCDIR=$CWD/$NAME-$VERSION
ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		

URL=http://users.zenwalk.org/user-accounts/skywatcher/$NAME/$VERSION
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Configure, make, install
cd $SRCDIR
./configure --prefix=/usr --mandir=/usr/man || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: GDMap (Graphical Disk Map) is a tool which allows to visualize disk
$NAME: space. Ever wondered why your hard disk is full or what directory
$NAME: and files take up most of the space? With GdMap these questions can
$NAME: be answered quickly. To display directory structures cushion treemaps
$NAME: are used which visualize a complete folder or even the whole hard
$NAME: drive with one picture.
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

#### Desktop entry
sed -i s:"Icon=gdmap_icon.png":"Icon=gdmap": $PKGDIR/usr/share/applications/$NAME.desktop
sed -i s:"Categories=Filesystem;Utility;GTK":"Categories=System;Utility;GTK": $PKGDIR/usr/share/applications/$NAME.desktop

### Icon
mv $PKGDIR/usr/share/pixmaps/gdmap_icon.png $ICONDIR/$NAME.png
cd $ICONDIR
mogrify -resize 48x48 $NAME.png

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Unnedeed stuff
rm -fr $PKGDIR/usr/share/pixmaps

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5sum and dep
cd $CWD
md5sum $PKG.tgz > $PKG.md5
requiredbuilder -z $PKG.tgz > $PKG.dep

### txt and src
cat $PKGDIR/install/slack-desc > $PKG.txt
rm -fr $PKG.src
for sources in $URL/$0 $SRCLNK
	do echo $sources >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done
echo "Done. Ciao!"

